/*  ---------------------------------------------------------------------------
    Program  :  CallPlotHistoN09.sas

    Path     :  C:\Your Path

    Purpose  :  Macro calls for Figures contained in N09 paper:
                Enhancing Textbook-Style Histograms with the PLOTHISTON09 SAS Macro

    ------------------------------------------------------------------------  */
%put FULLPATH: %sysget(SAS_EXECFILEPATH);
footnote1;
libname histo 'C:\N09\Histograms\Data';
 options mautosource;
 options sasautos=(sasautos 'C:\N09\Histograms\Mac');
 %annomac 
 %let outpath=C:\N09\Histograms\grf\emf;

 goptions reset=goptions;
 goptions device=EMF ctext=black htitle=6 htext=5 display 
   rotate=landscape gunit=pct polygonfill fill
   ftext="Arial" ftitle="Arial/Bold";

/* BASEBALL DATA */

data hitsAndRuns;
  set histo.baseball;
  if hits ne . and runs ne .;
run;

  /* HITS*/
proc sql noprint;
 select n(hits) into :Tot_N from work.hitsAndRuns;
quit;
*--------------------------------------------------------------------------;
/* FIGURE 4: UNIVARIATE VS PLOTHISTON09 WHERE HISTOCONFIG=1 */
 filename GSFOut "&outpath.\Fig4aUniv.emf";
 goptions gsfname=GSFOut gsfmode=replace;

title1 move=(+10pct,+0pct) "Baseball Hits via UNIVARIATE";
title2;
proc univariate data=work.hitsAndRuns normal noprint;
 histogram Hits / cfill=ltgray noframe 
                  endpoints=0 to 250 by 25
                  vscale=Count;  
 Label Hits='Hits'; 
run;

%PlotHistoN09(inds=work.hitsAndRuns, grfDevice=EMF, grfFile=%str(&outpath.\Fig4bMac.emf),
        barColor=ltgray, EMFbgColor=, mpTextColor=,
        xvar=hits, xmin=0, xmax=250, xdataOffset=2,
        HistoConfig=2, ConfigInfo=25, yorigin=12, pctSize=4.5, 
        XaxisLbl=Hits, xValFmt=3.,YaxisLbl=%str(Frequency), yby=10,
        mpLabelYvN=N, 
        title1=%str(Baseball Hits via macro: PLOTHISTON09 ),
        title2=);

  /* N-BAR HISTOGRAMS IN FIGURE 5 */
*--------------------------------------------------------------------------;
%PlotHistoN09(inds=work.hitsAndRuns, grfDevice=EMF, grfFile=%str(&outpath.\Fig5aMac.emf),
        barColor=ltgray, EMFbgColor=, mpLabelYvN=Y, mpTextColor=CX0386BE,
        xvar=hits, xmin=0, xmax=250, xdataOffset=1,
        HistoConfig=1, ConfigInfo=6, yorigin=12, pctSize=4.5, 
        XaxisLbl=Hits, xValFmt=3.,YaxisLbl=%str(Number of Players), yby=25,
        title1=%str(Baseball Data from 1986-1987),
        title2=%str(Total Number of Players = &Tot_N));

%PlotHistoN09(inds=work.hitsAndRuns, grfDevice=EMF, grfFile=%str(&outpath.\Fig5bMac.emf),
        barColor=ltgray, EMFbgColor=, mpLabelYvN=Y, mpTextColor=CX0386BE,
        xvar=hits, xmin=0, xmax=250, xdataOffset=1,
        HistoConfig=1, ConfigInfo=9, yorigin=12, pctSize=4.5, 
        XaxisLbl=Hits, xValFmt=3.,YaxisLbl=%str(Number of Players), yby=25,
        title1=%str(Baseball Data from 1986-1987),
        title2=%str(Total Number of Players = &Tot_N));

  /* UNEVEN BIN-WIDTH HISTOGRAMS IN FIGURE 6 */
*--------------------------------------------------------------------------;
%PlotHistoN09(inds=work.hitsAndRuns, grfDevice=EMF, grfFile=%str(&outpath.\Fig6aMac.emf),
        barColor=ltgray, EMFbgColor=, mpLabelYvN=Y, mpTextColor=CX0386BE,
        xvar=hits, xmin=0, xmax=250, xdataOffset=1,
        HistoConfig=3, ConfigInfo=%str(25 75 150 200), yorigin=12, pctSize=4.5, 
        XaxisLbl=Hits, xValFmt=3.,YaxisLbl=%str(Number of Players), yby=25,
        title1=%str(Baseball Data from 1986-1987),
        title2=%str(Total Number of Players = &Tot_N));

%PlotHistoN09(inds=work.hitsAndRuns, grfDevice=EMF, grfFile=%str(&outpath.\Fig6bMac.emf),
        barColor=ltgray, EMFbgColor=, mpLabelYvN=Y, mpTextColor=CX0386BE,
        xvar=hits, xmin=0, xmax=250, xdataOffset=1,
        HistoConfig=3, ConfigInfo=%str(50 75 125 163 200), yorigin=12, pctSize=4.5, 
        XaxisLbl=Hits, xValFmt=3.,YaxisLbl=%str(Number of Players), yby=25,
        title1=%str(Baseball Data from 1986-1987),
        title2=%str(Total Number of Players = &Tot_N));

 /* NORMAL CURVE WITH ASSOCIATED PROBABILITY IN FIGURE 10 */
*--------------------------------------------------------------------------;
ods listing close;
ods output TestsforNormality=ProbOut(where=(TestLab eq 'W'));
  proc univariate normal data=work.hitsAndRuns;
   var hits;
  run;
ods listing;
proc sql noprint;
  select pvalue into :ShapiroWilkPval
  from probout;
quit;

%PlotHistoN09(inds=work.hitsAndRuns, grfDevice=EMF, grfFile=%str(&outpath.\Fig10_MACRO.emf),
        barColor=ltgray, EMFbgColor=,
        xvar=hits, xmin=0, xmax=250, xdataOffset=2,
        HistoConfig=2, ConfigInfo=25, yorigin=12, pctSize=4.5, 
        XaxisLbl=Hits, xValFmt=3.,YaxisLbl=%str(Number of Players), yby=25,
        mpLabelYvN=N, CurveType=N, 
        title1=%str(Baseball Data from the PLOTHISTON09 Macro),
        title2=%str(n = &Tot_N   Prob(Norm) = &ShapiroWilkPval)
 );


 /* DENSITY CURVES IN FIGURE 11 */
*--------------------------------------------------------------------------;
  /* N-BAR HISTOGRAM WITH GAMMA CURVE FROM FIGURE 5 */
%PlotHistoN09(inds=work.hitsAndRuns, grfDevice=EMF, grfFile=%str(&outpath.\Fig11aCURVE.emf),
        barColor=ltgray, EMFbgColor=, mpLabelYvN=Y, mpTextColor=CX0386BE,
        xvar=hits, xmin=0, xmax=250, xdataOffset=1,
        HistoConfig=1, ConfigInfo=6, yorigin=12, pctSize=4.5, 
        XaxisLbl=Hits, xValFmt=3.,YaxisLbl=%str(Number of Players), yby=25,
        CurveType=G, 
        title1=%str(Baseball Data with a GAMMA Curve),
        title2=%str(Total Number of Players = &Tot_N));


  /* UNEVEN BIN-WIDTH HISTOGRAM WITH KDF CURVE FROM FIGURE 6 */
%PlotHistoN09(inds=work.hitsAndRuns, grfDevice=EMF, grfFile=%str(&outpath.\Fig11bCURVE.emf),
        barColor=ltgray, EMFbgColor=, mpLabelYvN=Y, mpTextColor=CX0386BE,
        xvar=hits, xmin=0, xmax=250, xdataOffset=1,
        HistoConfig=3, ConfigInfo=%str(50 75 125 163 200), yorigin=12, pctSize=4.5, 
        XaxisLbl=Hits, xValFmt=3.,YaxisLbl=%str(Number of Players), yby=25,
        CurveType=K,
        title1=%str(Baseball Data with a KERNEL DENSITY Curve),
        title2=%str(Total Number of Players = &Tot_N));

/* SUBGROUP HISTOGRAMS IN FIGURE 13 */
*--------------------------------------------------------------------------;
 /* Baseball Data with known SALARY */
  data Salary;
    set histo.baseball;
    if salary ne . ;
  run;

  proc sql noprint;
   create table countByLeagueSal
   as select League, count(*) as nLeague from salary
   group by League
   order by League;
   select nLeague into :nSL1 - :nSL2 from countByLeagueSal;
   select sum(nLeague) into :total from countByLeagueSal;
   %let total=%left(&total);
  quit;
  %let nSL1= %left(%trim(&nSL1));
  %let nSL2= %left(%trim(&nSL2));

  proc format;
    value cfmt 1='CX147A47' 2='CXA5DDFF';
    value LFmt 1="American (n=&nSL1)" 2="National (n=&nSL2)";
    value LPctFmt 1="American (n=&nSL1):100%" 2="National (n=&nSL2):100%";
  run;

 /* SUBGROUP HISTOGRAM -- FREQUENCIES */ 
 %PlotHistoN09(inds=work.salary, grfDevice=EMF, grfFile=%str(&outpath.\Fig13SalFrq.emf),
        EMFbgColor=white, mpLabelYvN=Y, mpTextColor=black,
        subGroupVar=League, colorFm=cfmt., sortByVorF=V, legendFmt=LFmt., xLgnd=65,
        xvar=salary, xmin=0, xmax=2500, xdataOffset=3.75,
        HistoConfig=2, ConfigInfo=500, yorigin=12, pctSize=4.5, 
        XaxisLbl=Salary, YaxisLbl=Frequency, xValFmt=$dollar10., yby=25,      
        title1=%str(Baseball Data by League from 1986-1987),
        title2=%str((Total = &Total))
        );

 /* SUBGROUP HISTOGRAM -- PERCENTS */ 
 %PlotHistoN09(inds=work.salary, grfDevice=EMF, grfFile=%str(&outpath.\Fig13Salpct.emf),
        EMFbgColor=white, mpLabelYvN=Y, mpTextColor=black,
        subGroupVar=League, colorFm=cfmt., sortByVorF=V, legendFmt=LpctFmt., xLgnd=65,
        xvar=salary, xmin=0, xmax=2500, xdataOffset=3.75,
        HistoConfig=2, ConfigInfo=500, yorigin=12, pctSize=4.5, 
        XaxisLbl=Salary, YaxisLbl=Percent, xValFmt=$dollar10., yby=25,      
        title1=%str(Baseball Data by League from 1986-1987),
        title2=%str((Total = &Total))
        );
