/*  ---------------------------------------------------------------------------
    Program  :  getAxisMax.sas

    Path     :  C:\Your Path

    Purpose  :  Obtain displayed maximum for a histogram where a BY value
                 is supplied to the PLOTHISTO (calling) macro.

    Parms    :  Name           Description                   Default
               ---------  --------------------------------   --------
               Max         Maximum value derived from data   
               By          By value entered by user           

    examples : %let XMax = %getAxisMax(Max=&XMAX, by=0.67);
               IF
                &XMAX resolves to 6 then &AdjMax also resolves to 6
                &XMAX resolves to 4 then &AdjMax resolves to 4.67             
       ------------------------------------------------------------------------  */
  %macro getAxisMax(Max=, by=);
  %Local adjmax intby intmax modx multiplier notfound ;
  %let notFound = 1;
  %let multiplier = 1;
  %do %while (&notFound);  
    %let intMax=%sysevalf( &multiplier * &Max);
    %let intBy=%sysevalf(&multiplier * &by);
    %if %sysfunc(floor(&intBy)) ne %sysfunc(ceil(&intBy)) %then %do;
       %let multiplier = %sysevalf(&multiplier * 10.0);
    %end;
    %else %do;
       %let notFound = 0;
    %end;
  %end;
  %let intMax=%sysfunc(ceil(&intMax));
  %let modX = %sysfunc(mod(&intMax,&intBy));
  %do %while (%eval(&modX) ne 0);
    %let intMax=%eval(&intMax +1);
    %let modX = %sysfunc(mod(&intMax,&intBy));
  %end;
  %let AdjMax=%sysevalf(&intMax/&multiplier);
  %let diff=%sysfunc(abs(%sysevalf(&adjMAX - &MAX)));
  %if &diff ne 0 %then %put !!**!! Data Max &MAX is Not divisible by &By;
  &AdjMax
 %mend getAxisMax;
