/*  ---------------------------------------------------------------------------
    Program  :  getAxisMin.sas

    Path     :  C:\Your Path

    Purpose  :  Obtain displayed minimum for a histogram where a BY value
                 is supplied to the PLOTHISTO (calling) macro.

    Parms    :  Name           Description                   Default
               ---------  --------------------------------   --------
               Min         minimum value derived from data    
               By          By value entered by user           

    example  : %let YMIN = %getAxisMin(Min=0.9321, by=0.02);
               %put &YMIN; -> 0.92
    ------------------------------------------------------------------------  */
 %macro getAxisMin(Min=, by=);
  %Local adjmin intby intmin modx multiplier notfound ;
  %let notFound = 1;
  %let multiplier = 1;
  %do %while (&notFound);  
    %let intMin=%sysevalf(&multiplier * &Min);
    %let intBy=%sysevalf(&multiplier * &by);
    %if %sysfunc(floor(&intBy)) ne %sysfunc(ceil(&intBy)) %then %do;
       %let multiplier = %sysevalf(&multiplier * 10.0);
    %end;
    %else %do;
       %let notFound = 0;
    %end;
  %end;
  %let intMin=%sysfunc(floor(&intMin));
  %let modX = %sysfunc(mod(&intMin,&intBy));
  %do %while (%eval(&modX) ne 0);
    %let intMin=%eval(&intMin -1);
    %let modX = %sysfunc(mod(&intMin,&intBy));
  %end;
  %let AdjMin=%sysevalf(&intMin/&multiplier);
  %let diff=%sysfunc(abs(%sysevalf(&adjMin - &Min)));
  %if &diff ne 0 %then %put WARNING !!**!! Data Min &Min is Not divisible by &By;

  &Adjmin
 %mend getAxisMin;
 
