/*  ---------------------------------------------------------------------------
    Program  :  mkUnderlyingScale.sas

    Path     :  C:\Your Path

    Purpose  :  Macro function that creates an order statement in a hidden 
                axis where the distance between major tick marks is very small.
                
    Output   :  An explicit range in &XMIN to &XMAX by &Xby format.

    Parms    :  NAME            DESCRIPTION                             DEFAULT
                ---------       --------------------------------        --------
                CALCXMIN        XMIN calculated from input data         none (required)
                                  in the calling program
                CALCXMAX        XMAX calculated from input data         none (required)
                                  in the calling program
                OFFSET          IF GT 0 then adjust CALCXMIN by         none (required)
                                -&OFFSET * &XBY and CALCXMAX by
                                +&OFFSET*&XBY.
    Macros
    Called   :  GETINCR         Calculates the narrow increment used in the
                                order statement and used to stretch the
                                axis when desired.
                GETAXISMIN      Re-calculates Axis minimum with output from
                                GETINCR.
                GETAXISMAX      Re-calculates Axis maximum with output from
                                GETINCR.
    ------------------------------------------------------------------------  */
%put FULLPATH: %sysget(SAS_EXECFILEPATH);
 %macro MkUnderlyingScale(calcXMin=, calcXMax=, offset=);
    %local rangeX xBy xmin xmax;
    %let rangeX = %sysevalf(&calcXMax - &calcXmin);
    %let xBy= %getIncr(range=&rangeX);
    %let calcXmin = %sysevalf(&calcXmin - &xBy);
    %let calcXmax = %sysevalf(&calcXmax + &xBy);
    %if &OffSet gt 0 %then %do;
      %let calcXmin=%sysevalf(&calcXmin - (&offset * &Xby) );
      %let calcXmax=%sysevalf(&calcXmax + (&offset * &Xby) );
    %end;
     /* FINAL ENDPOINTS WHERE XMIN AND XMAX ARE FACTORS OF XBY 
     SUPPLIED BY MACRO FUNCTION*/    
     %let xMin=%getAxisMin(min=&calcXmin, by=&Xby);
     %let xMax=%getAxisMax(max=&calcXmax, by=&Xby);
     &XMIN to &XMAX by &Xby
%mend MkUnderlyingScale;
